#!/usr/bin/env python
# -*- coding: utf-8 -*-
# ˅
import os
import sys

# Add the current directory to the system path
sys.path.insert(0, os.path.dirname(__file__))

from image import Image
from image_configuration import ImageConfiguration

## @brief Main function to load an image, apply a mask, and display it.
#
# This function uses the ImageConfiguration class to load the configuration
# and the Image class to process and display the image.
def main():
    # Load the image configuration from the environment file
    image_config = ImageConfiguration("image_configuration.env")

    # Load the image using the file path from the configuration
    image = Image(image_config.getImageFilePath())

    # Apply a mask to the image based on the configuration
    image.mask(
        image_config.getSide(),
        image_config.getProjectionWidthCm(),
        image_config.getDistanceBetweenProjectorCm(),
        image_config.getGammaValue()
    )

    # Display the processed image
    image.displayImage()


## @brief Entry point of the script.
#
# Executes the main function when the script is run.
if __name__ == '__main__':
    main()